==> dokuwiki-2014.09.29b.tgz: dokuwiki/lib/plugins/extension/lang/hr/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Davor Turkalj <turki.bsc@gmail.com>
 */
$lang['menu']                  = 'Upravitelj dodataka';
$lang['tab_plugins']           = 'Instalirani dodatci';
$lang['tab_templates']         = 'Instalirani predlošci';
$lang['tab_search']            = 'Potraži i instaliraj';
$lang['tab_install']           = 'Ručno instaliranje';
$lang['notimplemented']        = 'Ova mogućnost još nije napravljena';
$lang['notinstalled']          = 'Dodatak nije instaliran';
$lang['alreadyenabled']        = 'Ovaj dodatak je već omogućen';
$lang['alreadydisabled']       = 'Ovaj dodatak je već onemogućen';
$lang['pluginlistsaveerror']   = 'Dogodila se greška pri snimanju liste dodataka';
$lang['unknownauthor']         = 'Nepoznat autor';
$lang['unknownversion']        = 'Nepoznata inačica';
$lang['btn_info']              = 'Prikaži više informacija';
$lang['btn_update']            = 'Dopuni';
$lang['btn_uninstall']         = 'Ukloni';
$lang['btn_enable']            = 'Omogući';
$lang['btn_disable']           = 'Onemogući';
$lang['btn_install']           = 'Postavi';
$lang['btn_reinstall']         = 'Ponovno postavi';
$lang['js']['reallydel']       = 'Zaista ukloniti ovo proširenje?';
$lang['search_for']            = 'Pretraži proširenja';
$lang['search']                = 'Pretraži';
$lang['extensionby']           = '<strong>%s</strong> po %s';
$lang['screenshot']            = 'Slika zaslona od %s';
$lang['popularity']            = 'Popularnost: %s%%';
$lang['homepage_link']         = 'Upute';
$lang['bugs_features']         = 'Greške';
$lang['tags']                  = 'Oznake:';
$lang['author_hint']           = 'Potraži dodatke od ovog autora';
$lang['installed']             = 'Postavljeno:';
$lang['downloadurl']           = 'URL adresa preuzimanja:';
$lang['repository']            = 'Repozitorij:';
$lang['unknown']               = '<em>nepoznat</em>';
$lang['installed_version']     = 'Postavljena inačica:';
$lang['install_date']          = 'Vaše zadnje osvježavanje:';
$lang['available_version']     = 'Dostupna inačica';
$lang['compatible']            = 'Kompatibilan s:';
$lang['depends']               = 'Zavisi o:';
$lang['similar']               = 'Sličan s:';
$lang['conflicts']             = 'U sukobu s:';
$lang['donate']                = 'Poput ovog?';
$lang['donate_action']         = 'Kupite autoru kavu!';
$lang['repo_retry']            = 'Ponovi';
$lang['provides']              = 'Osigurava:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'ugrađen';
$lang['status_not_installed']  = 'nije ugrađen';
$lang['status_protected']      = 'zaštićen';
$lang['status_enabled']        = 'omogućen';
$lang['status_disabled']       = 'onemogućen';
$lang['status_unmodifiable']   = 'neizmjenjiv';
$lang['status_plugin']         = 'dodatak';
$lang['status_template']       = 'predložak';
$lang['status_bundled']        = 'ugrađen';
$lang['msg_enabled']           = 'Dodatak %s omogućen';
$lang['msg_disabled']          = 'Dodatak %s onemogućen';
$lang['msg_delete_success']    = 'Proširenje uklonjeno';
$lang['msg_template_install_success'] = 'Predložak %s uspješno ugrađen';
$lang['msg_template_update_success'] = 'Predložak %s uspješno nadograđen';
$lang['msg_plugin_install_success'] = 'Dodatak %s uspješno ugrađen';
$lang['msg_plugin_update_success'] = 'Dodatak %s uspješno nadograđen';
$lang['msg_upload_failed']     = 'Učitavanje datoteke nije uspjelo';
$lang['missing_dependency']    = '<strong>Nedostaje ili onemogućena zavisnost:</strong> %s';
$lang['security_issue']        = '<strong>Sigurnosno pitanje:</strong> %s';
$lang['security_warning']      = '<strong>Sigurnosno upozorenje:</strong> %s';
$lang['update_available']      = '<strong>Nadogranja:</strong> Nova inačica %s je dostupna.';
$lang['wrong_folder']          = '<strong>Dodatak neispravno ugrađen:</strong> Preimenujte mapu dodatka iz "%s" u "%s".';
$lang['url_change']            = '<strong>URL izmijenjen:</strong> Adresa za preuzimanje je promijenjena od zadnjeg preuzimanja. Provjerite da li je novu URL valjan prije nadogradnje proširenja.<br />Novi: %s<br />Stari: %s';
$lang['error_badurl']          = 'URL adrese trebaju započinjati sa http ili https';
$lang['error_dircreate']       = 'Ne mogu napraviti privremenu mapu za prihvat preuzimanja';
$lang['error_download']        = 'Ne mogu preuzeti datoteku: %s';
$lang['error_decompress']      = 'Ne mogu raspakirati preuzetu datoteku. To može biti rezultati lošeg preuzimanja i tada treba pokušati ponovo; ili format sažimanja je nepoznat i u tom slučaju treba datoteku ručno preuzeti i ugraditi.';
$lang['error_findfolder']      = 'Ne mogu odrediti mapu proširenja, trebate ga ručno preuzeti i ugraditi';
$lang['error_copy']            = 'Dogodila se greška pri kopiranju dok je pokušavanja ugradnja datoteka u mapu <em>%s</em>: disk može biti pun ili dozvole pristupa nisu dobre. Ovo može rezultirati djelomično ugrađenim dodatkom i može učiniti Vaš wiki nestabilnim';
$lang['noperms']               = 'Nije moguće pisati u mapu proširanja';
$lang['notplperms']            = 'Nije moguće pisati u mapu predloška';
$lang['nopluginperms']         = 'Nije moguće pisati u mapu dodatka';
$lang['git']                   = 'Proširenje je ugrađeno preko Git-a, možda ga ne želite nadograđivati ovdje.';
$lang['install_url']           = 'Ugradi s URL-a:';
$lang['install_upload']        = 'Učitaj proširenje:';
$lang['repo_error']            = 'Repozitorij dodataka nije dostupan. Budite sigurni da server može pristupiti www.dokuwiki.org i provjerite proxy postavke.';

==> dokuwiki-2015.08.10a.tgz: dokuwiki/lib/plugins/extension/lang/hr/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Davor Turkalj <turki.bsc@gmail.com>
 */
$lang['menu']                  = 'Upravitelj proširenja';
$lang['tab_plugins']           = 'Ugrađeni dodatci';
$lang['tab_templates']         = 'Ugrađeni predlošci';
$lang['tab_search']            = 'Potraži i ugradi';
$lang['tab_install']           = 'Ručna ugradnja';
$lang['notimplemented']        = 'Ova mogućnost još nije napravljena';
$lang['notinstalled']          = 'Proširenje nije ugrađeno';
$lang['alreadyenabled']        = 'Ovo proširenje je već omogućeno';
$lang['alreadydisabled']       = 'Ovo proširenje je već onemogućeno';
$lang['pluginlistsaveerror']   = 'Dogodila se greška pri snimanju liste dodataka';
$lang['unknownauthor']         = 'Nepoznat autor';
$lang['unknownversion']        = 'Nepoznata inačica';
$lang['btn_info']              = 'Prikaži više informacija';
$lang['btn_update']            = 'Ažuriraj';
$lang['btn_uninstall']         = 'Ukloni';
$lang['btn_enable']            = 'Omogući';
$lang['btn_disable']           = 'Onemogući';
$lang['btn_install']           = 'Ugradi';
$lang['btn_reinstall']         = 'Ponovno ugradi';
$lang['js']['reallydel']       = 'Zaista ukloniti ovo proširenje?';
$lang['search_for']            = 'Pretraži proširenja';
$lang['search']                = 'Pretraži';
$lang['extensionby']           = '<strong>%s</strong> po %s';
$lang['screenshot']            = 'Slika zaslona od %s';
$lang['popularity']            = 'Popularnost: %s%%';
$lang['homepage_link']         = 'Upute';
$lang['bugs_features']         = 'Greške';
$lang['tags']                  = 'Oznake:';
$lang['author_hint']           = 'Potraži proširenja od ovog autora';
$lang['installed']             = 'Ugrađeno:';
$lang['downloadurl']           = 'URL adresa preuzimanja:';
$lang['repository']            = 'Repozitorij:';
$lang['unknown']               = '<em>nepoznat</em>';
$lang['installed_version']     = 'Ugrađena inačica:';
$lang['install_date']          = 'Vaše zadnje osvježavanje:';
$lang['available_version']     = 'Dostupna inačica';
$lang['compatible']            = 'Kompatibilan s:';
$lang['depends']               = 'Zavisi o:';
$lang['similar']               = 'Sličan s:';
$lang['conflicts']             = 'U sukobu s:';
$lang['donate']                = 'Poput ovog?';
$lang['donate_action']         = 'Kupite autoru kavu!';
$lang['repo_retry']            = 'Ponovi';
$lang['provides']              = 'Osigurava:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'ugrađen';
$lang['status_not_installed']  = 'nije ugrađen';
$lang['status_protected']      = 'zaštićen';
$lang['status_enabled']        = 'omogućen';
$lang['status_disabled']       = 'onemogućen';
$lang['status_unmodifiable']   = 'neizmjenjiv';
$lang['status_plugin']         = 'dodatak';
$lang['status_template']       = 'predložak';
$lang['status_bundled']        = 'ugrađen';
$lang['msg_enabled']           = 'Dodatak %s omogućen';
$lang['msg_disabled']          = 'Dodatak %s onemogućen';
$lang['msg_delete_success']    = 'Proširenje %s uklonjeno';
$lang['msg_delete_failed']     = 'Uklanjanje proširenja %s nije uspjelo';
$lang['msg_template_install_success'] = 'Predložak %s uspješno ugrađen';
$lang['msg_template_update_success'] = 'Predložak %s uspješno nadograđen';
$lang['msg_plugin_install_success'] = 'Dodatak %s uspješno ugrađen';
$lang['msg_plugin_update_success'] = 'Dodatak %s uspješno nadograđen';
$lang['msg_upload_failed']     = 'Učitavanje datoteke nije uspjelo';
$lang['missing_dependency']    = '<strong>Nedostaje ili onemogućena zavisnost:</strong> %s';
$lang['security_issue']        = '<strong>Sigurnosno pitanje:</strong> %s';
$lang['security_warning']      = '<strong>Sigurnosno upozorenje:</strong> %s';
$lang['update_available']      = '<strong>Nadogranja:</strong> Nova inačica %s je dostupna.';
$lang['wrong_folder']          = '<strong>Dodatak neispravno ugrađen:</strong> Preimenujte mapu dodatka iz "%s" u "%s".';
$lang['url_change']            = '<strong>URL izmijenjen:</strong> Adresa za preuzimanje je promijenjena od zadnjeg preuzimanja. Provjerite da li je novu URL valjan prije nadogradnje proširenja.<br />Novi: %s<br />Stari: %s';
$lang['error_badurl']          = 'URL adrese trebaju započinjati sa http ili https';
$lang['error_dircreate']       = 'Ne mogu napraviti privremenu mapu za prihvat preuzimanja';
$lang['error_download']        = 'Ne mogu preuzeti datoteku: %s';
$lang['error_decompress']      = 'Ne mogu raspakirati preuzetu datoteku. To može biti rezultati lošeg preuzimanja i tada treba pokušati ponovo; ili format sažimanja je nepoznat i u tom slučaju treba datoteku ručno preuzeti i ugraditi.';
$lang['error_findfolder']      = 'Ne mogu odrediti mapu proširenja, trebate ga ručno preuzeti i ugraditi';
$lang['error_copy']            = 'Dogodila se greška pri kopiranju dok je pokušavanja ugradnja datoteka u mapu <em>%s</em>: disk može biti pun ili dozvole pristupa nisu dobre. Ovo može rezultirati djelomično ugrađenim dodatkom i može učiniti Vaš wiki nestabilnim';
$lang['noperms']               = 'Nije moguće pisati u mapu proširanja';
$lang['notplperms']            = 'Nije moguće pisati u mapu predloška';
$lang['nopluginperms']         = 'Nije moguće pisati u mapu dodatka';
$lang['git']                   = 'Proširenje je ugrađeno preko Git-a, možda ga ne želite nadograđivati ovdje.';
$lang['auth']                  = 'Autorizacijski dodatak nije podešen, razmotrite njegovo onemogućavanje kao dodatka.';
$lang['install_url']           = 'Ugradi s URL-a:';
$lang['install_upload']        = 'Učitaj proširenje:';
$lang['repo_error']            = 'Repozitorij dodataka nije dostupan. Budite sigurni da server može pristupiti www.dokuwiki.org i provjerite proxy postavke.';
$lang['nossl']                 = 'Izgleda da korišteni PHP ne podržava SSL. Učitavanje neće raditi na mnogim DokuWiki dodatcima.';
